@@ -2,8 +2,9 @@
 """
 Example of multiple individual completers that are combined into one.
 """
+
 from prompt_toolkit import prompt
-from prompt_toolkit.completion import Completer, WordCompleter, merge_completers
+from prompt_toolkit.completion import WordCompleter, merge_completers
 
 animal_completer = WordCompleter(
     [
@@ -69,7 +70,7 @@ def main():
     text = prompt(
         "Give some animals: ", completer=completer, complete_while_typing=False
     )
-    print("You said: %s" % text)
+    print(f"You said: {text}")
 
 
 if __name__ == "__main__":
