@@ -2,8 +2,9 @@
 """
 The most simple prompt example.
 """
+
 from prompt_toolkit import prompt
 
 if __name__ == "__main__":
     answer = prompt("Give me some input: ")
-    print("You said: %s" % answer)
+    print(f"You said: {answer}")
