@@ -3,4 +3,4 @@ from prompt_toolkit import prompt
 
 if __name__ == "__main__":
     answer = prompt("Give me some input: ", wrap_lines=False, multiline=True)
-    print("You said: %s" % answer)
+    print(f"You said: {answer}")
